calculate_total_survivors: Calculate Total Survivors

Description Usage Arguments Value

View source: R/prey_survival_simulation.R

Description

Simply calculates the total number of surviving fish based on the output of calculate_final_status()

Usage

1
calculate_total_survivors(final_status_frame)

Arguments

final_status_frame

dataframe with final status of each fish; see calculate_final_status()

Value

an integer of the number of survivng prey fish


mrguyperson/predpackplus documentation built on Dec. 21, 2021, 10:08 p.m.