create_stream_raster_frame: Environmental Raster

Description Usage Arguments Value Examples

View source: R/generate_preds_and_encs.R

Description

Creates and overlays a raster onto the predator positions raster size mimics the cells in netlogo returns a data.frame with coordinates for the cells and counts of fish in each cell

Usage

1
2
3
4
5
6
7
create_stream_raster_frame(
  df,
  transect_length = 1000,
  channel_width = 100,
  grid_size = 15,
  n_transects = 20
)

Arguments

df

dataframe of predator position data; use get_pred_positions function

transect_length

length of each transect in meters; default is 1000

channel_width

width of the channel in meters; default is 100

grid_size

length of side of raster grid in meters; default is 15

n_transects

integer of transects in the model; default is 20

Value

a dataframe of raster coordinates

Examples

1
2

mrguyperson/predpackplus documentation built on Dec. 21, 2021, 10:08 p.m.