Description Usage Arguments Value
View source: R/prey_survival_simulation.R
Simply calculates the total number of surviving fish based on the output of calculate_final_status()
1 | calculate_total_survivors(final_status_frame)
|
final_status_frame |
dataframe with final status of each fish; see calculate_final_status() |
an integer of the number of survivng prey fish
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.